summaryrefslogtreecommitdiff
path: root/gcc/config/i386/linux-aout.h
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/config/i386/linux-aout.h')
-rw-r--r--gcc/config/i386/linux-aout.h12
1 files changed, 7 insertions, 5 deletions
diff --git a/gcc/config/i386/linux-aout.h b/gcc/config/i386/linux-aout.h
index f7d807a10d0..349642fa7c7 100644
--- a/gcc/config/i386/linux-aout.h
+++ b/gcc/config/i386/linux-aout.h
@@ -1,5 +1,5 @@
-/* Definitions for Intel 386 running Linux
- Copyright (C) 1992, 1994, 1995 Free Software Foundation, Inc.
+/* Definitions for Intel 386 running Linux-based GNU systems using a.out.
+ Copyright (C) 1992, 1994, 1995, 1997 Free Software Foundation, Inc.
Contributed by H.J. Lu (hjl@nynexst.com)
This file is part of GNU CC.
@@ -25,6 +25,9 @@ Boston, MA 02111-1307, USA. */
#include <i386/gstabs.h>
#include <linux-aout.h> /* some common stuff */
+#undef ASM_COMMENT_START
+#define ASM_COMMENT_START "#"
+
/* Specify predefined symbols in preprocessor. */
#undef CPP_PREDEFINES
@@ -53,9 +56,8 @@ Boston, MA 02111-1307, USA. */
#if 1
/* We no longer link with libc_p.a or libg.a by default. If you
- * want to profile or debug the Linux C library, please add
- * -lc_p or -ggdb to LDFLAGS at the link time, respectively.
- */
+ want to profile or debug the GNU/Linux C library, please add
+ -lc_p or -ggdb to LDFLAGS at the link time, respectively. */
#define LIB_SPEC \
"%{mieee-fp:-lieee} %{p:-lgmon} %{pg:-lgmon} %{!ggdb:-lc} %{ggdb:-lg}"
#else